@@ -4,15 +4,17 @@ use strict;
 use warnings;
 use Cwd;
 use Plack::Runner;
+use Term::ANSIColor;
 
-our $VERSION = '0.02';
+our $VERSION = '0.04';
 
 sub new {
     my $class = shift;
     my $path  = shift;
     
     return bless {
-        path => $path ? $path : getcwd
+        path => $path ? $path : getcwd,
+        type => ''
     }, $class;
 }
 
@@ -47,17 +49,22 @@ sub run {
 }
 
 sub _type {
-    my $path = shift->{path};
+    my $self = shift;
+    
+    my $path = $self->{path};
     
     my $type = {};
         
     if (-d $path) {
+        $self->{type} = 'Folder';
         $type->{module} = 'Plack::App::WWW';
         $type->{eval}   = "Plack::App::WWW->new(root => '$path')->to_app";        
     } elsif (-e $path && $path =~ /\.(pl|cgi)$/i) {
+        $self->{type} = 'File';
         $type->{module} = 'Plack::App::WrapCGI';
         $type->{eval}   = "Plack::App::WrapCGI->new(script => '$path')->to_app";         
     } else {
+        $self->{type} = 'PSGI';
         $type->{app} = $path;
     }
     
@@ -69,12 +76,43 @@ sub _message {
     
     push @{$runner->{options}}, server_ready => sub {
         my $args = shift;
-        my $host  = $args->{host}  || 0;
-        my $proto = $args->{proto} || 'http';
-        print STDERR "Perl::Server: Accepting connections at $proto://$host:$args->{port}/\n";
+        my $server = $args->{server_software} || ref($args);
+        my $host   = $args->{host}  || 0;
+        my $proto  = $args->{proto} || 'http';
+        my $port   = $args->{port};
+        
+        $self->_name;
+        $self->_print('Version', $VERSION);
+        $self->_print('Server', $server);
+        $self->_print('Type', $self->{type});
+        $self->_print('Path', $self->{path});
+        $self->_print('Available on', "$proto://$host:$port");
+        $self->_stop;
     };     
 }
 
+sub _name {
+    print STDERR color('bold blue');
+    print STDERR "Perl::Server\n\n";    
+}
+
+sub _stop {
+    print STDERR color('reset');
+    print STDERR color('white');    
+    print STDERR "\nHit CTRL-C to stop the perl-server\n";
+}
+
+sub _print {
+    my ($self, $name, $value) = @_;
+    
+    print STDERR color('reset');
+    print STDERR color('yellow');
+    print STDERR "$name: ";
+    print STDERR color('reset');
+    print STDERR color('green');
+    print STDERR "$value\n";      
+}
+
 1;
 
 __END__
